@@ -1,5 +1,7 @@
 import os
+import time
 import tkinter as tk
+from re import S
 from tkinter import filedialog as fd
 from tkinter import simpledialog as sd
 from tkinter.colorchooser import askcolor
@@ -7,8 +9,8 @@ from tkinter.colorchooser import askcolor
 import pynput
 from PIL import Image, ImageTk
 
-from ..resources.language import Text
 from ..resources.info import show_info
+from ..resources.language import Text
 from .dose_figure_handler import DoseFigureHandler
 from .profile import ProfileHandler
 from .xrangeslider import XRangeSlider
@@ -18,9 +20,36 @@ class MainApplication(tk.Frame):
     def __init__(self, parent):
 
         tk.Frame.__init__(self, parent)
+        self.starttime = time.time()
 
         self.parent = parent
 
+        self.logocanvas = tk.Canvas(self)
+        self.logocanvas.pack(side=tk.TOP, fill="both", expand=True)
+        self.center = [
+            (self.winfo_screenwidth() // 2 + 50) // 2,
+            (self.parent.winfo_screenheight() // 2) // 2,
+        ]
+        self.logo = ImageTk.PhotoImage(
+            Image.open(
+                os.path.join(
+                    os.path.dirname(os.path.realpath(__file__)),
+                    "..",
+                    "resources",
+                    "icon.png",
+                )
+            ).resize(
+                (self.parent.minsize()[0] // 4, (self.parent.minsize()[0] // 4)),
+                Image.LANCZOS,
+            ),
+            master=self.logocanvas,
+        )
+        self.logo_on_canvas = self.logocanvas.create_image(
+            self.center[0], self.center[1], anchor=tk.CENTER, image=self.logo,
+        )
+        self.logocanvas.image = self.logo
+        self.logocanvas.itemconfig(self.logo_on_canvas, image=self.logocanvas.image)
+
         self.parent.protocol("WM_DELETE_WINDOW", lambda: self.save_graph(True))
 
         # Read settings from profile.json and initialize the necessary variables
@@ -90,6 +119,7 @@ class MainApplication(tk.Frame):
         self.DoseFigureHandler = DoseFigureHandler(self)
 
         # Keybinding definitions
+        self.parent.bind("<Configure>", self.handle_configure)
         self.parent.bind("<Control-e>", lambda type: self.load_file("egs"))
         self.parent.bind("<Control-d>", lambda type: self.load_file("dp"))
         self.parent.bind("<Control-o>", lambda type: self.load_file("simulation"))
@@ -408,29 +438,6 @@ class MainApplication(tk.Frame):
 
         self.parent.title(self.text.window_title[self.lang])
 
-        self.logo = ImageTk.PhotoImage(
-            Image.open(
-                os.path.join(
-                    os.path.dirname(os.path.realpath(__file__)),
-                    "..",
-                    "resources",
-                    "icon.png",
-                )
-            ).resize(
-                (self.parent.minsize()[0] // 4, (self.parent.minsize()[0] // 4)),
-                Image.LANCZOS,
-            )
-        )
-        self.logocanvas = tk.Canvas(self)
-        self.logo_on_canvas = self.logocanvas.create_image(
-            0, 0, anchor=tk.NW, image=self.logo
-        )
-        self.logocanvas.image = self.logo
-        self.canvas.itemconfig(self.logo_on_canvas, image=self.logocanvas.image)
-        self.logocanvas.place(
-            relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-        )
-
         self.pack(side="top", fill="both", expand=True)
 
         self.parent.attributes("-fullscreen", self.fullscreen.get())
@@ -460,29 +467,18 @@ class MainApplication(tk.Frame):
 
         if theme == "light":
             self.parent.tk.call("set_theme", "light")
-            self.logocanvas.place_forget()
             self.logocanvas.configure(background="#ffffff")
             self.parent.configure(background="#ffffff")
-            self.logocanvas.place(
-                relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-            )
-
-            if self.filenames != []:
-                self.show_preview()
 
         else:
             # Set dark theme
             self.parent.tk.call("set_theme", "dark")
-
             self.parent.configure(background="#363636")
-            self.logocanvas.place_forget()
             self.logocanvas.configure(background="#333333")
-            self.logocanvas.place(
-                relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-            )
-            if self.filenames != []:
-                self.logocanvas.place_forget()
-                self.show_preview()
+
+        if self.filenames != []:
+            self.logocanvas.pack_forget()
+            self.show_preview()
 
         return
 
@@ -578,9 +574,6 @@ class MainApplication(tk.Frame):
         self.parent.config(menu=None)
         self.profile.set_attribute("language", language)
         self.__init__(self.parent)
-        if dark == True:
-            self.switchtheme("dark")
-            self.dark.set(True)
         if plots != []:
             self.filenames = filenames
             self.DoseFigureHandler.plots = plots
@@ -598,6 +591,12 @@ class MainApplication(tk.Frame):
             self.DoseFigureHandler.diffplot = diffplot
             self.DoseFigureHandler.errlimmin = errlimmin
             self.DoseFigureHandler.errlimmax = errlimmax
+            if dark == True:
+                self.switchtheme("dark")
+                self.dark.set(True)
+            else:
+                self.switchtheme("light")
+                self.dark.set(False)
             self.show_preview()
 
         return
@@ -624,7 +623,7 @@ class MainApplication(tk.Frame):
 
         for file in self.current_file:
             self.filenames += [(file, type)]
-        self.logocanvas.place_forget()
+        self.logocanvas.pack_forget()
         self.show_preview()
         self.filemenu.entryconfig(0, state=tk.DISABLED)
         self.filemenu.entryconfig(1, state=tk.DISABLED)
@@ -636,11 +635,59 @@ class MainApplication(tk.Frame):
 
         return
 
+    def load_dropped_file(self, files):
+        """Loads measurement or simulation data to be displayed
+        """
+
+        for i, character in enumerate(files):
+            if character == " ":
+                if files[i + 1] == "{":
+                    files = files[:i] + ";" + files[i + 1 :]
+                else:
+                    if files[:i].count("{") == files[:i].count("}"):
+                        files = files[:i] + ";" + files[i + 1 :]
+
+        files = files.split(";")
+        for i, file in enumerate(files):
+            if "{" in file:
+                files[i] = file[1:-1]
+
+        types = {
+            "csv": "simulation",
+            "3ddose": "egs",
+            "bin": "simulation",
+            "mcc": "ptw",
+        }
+        extensions = []
+        for i, file in enumerate(files):
+            try:
+                extensions += [types[file.split(".")[-1]]]
+            except KeyError:
+                files.pop(i)
+
+        self.current_file = files
+
+        for i, file in enumerate(self.current_file):
+            self.filenames += [(file, extensions[i])]
+
+        if len(self.filenames) == 0:
+            return
+
+        self.logocanvas.pack_forget()
+        self.show_preview()
+        self.filemenu.entryconfig(0, state=tk.DISABLED)
+        self.filemenu.entryconfig(1, state=tk.DISABLED)
+        self.filemenu.entryconfig(3, state=tk.NORMAL)
+        self.filemenu.entryconfig(4, state=tk.NORMAL)
+        if len(self.filenames) > 2:
+            self.normmenu.entryconfig(12, state=tk.DISABLED)
+        self.saved = False
+
     def close_file(self, event=None):
 
         """Closes the current project
         """
-        self.canvas.place_forget()
+        self.canvas.pack_forget()
         self.filemenu.entryconfig(0, state=tk.NORMAL)
         self.filemenu.entryconfig(1, state=tk.NORMAL)
         self.filemenu.entryconfig(3, state=tk.DISABLED)
@@ -669,6 +716,7 @@ class MainApplication(tk.Frame):
         self.menuflag = False
         self.current_limits = []
         self.initial_limits = []
+        self.rename_boxes = []
         self.slidervars = [tk.DoubleVar(), tk.DoubleVar()]
         self.DoseFigureHandler.caxcorrection = False
         self.caxcorrection.set(False)
@@ -677,9 +725,11 @@ class MainApplication(tk.Frame):
             self.xlimmenu = False
         except AttributeError:
             pass
-        self.logocanvas.place(
-            relx=0.41233, rely=0.3441, relheight=1, relwidth=1,
-        )
+        deltax = self.winfo_width() // 2 - self.center[0]
+        deltay = self.winfo_height() // 2 - self.center[1]
+        self.center = [self.winfo_width() // 2, self.winfo_height() // 2]
+        self.logocanvas.move(self.logo_on_canvas, deltax, deltay)
+        self.logocanvas.pack(side=tk.TOP, fill="both", expand=True)
         return
 
     def save_graph(self, exit=False):
@@ -936,9 +986,9 @@ class MainApplication(tk.Frame):
             self.filenames
         )
 
-        self.canvas.place_forget()
+        self.logocanvas.pack_forget()
+        self.canvas.pack_forget()
         self.canvas = tk.Canvas(self)
-        self.canvas.bind("<Configure>", self.handle_configure)
         self.canvas.bind("<Button-1>", self.check_click)
         self.canvas.bind("<Button-3>", self.check_right_click)
         self.canvas.bind("<Motion>", self.check_hand)
@@ -946,6 +996,8 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Up>", lambda boolean: self.change_order(True))
         self.parent.bind("<Down>", lambda boolean: self.change_order(False))
 
+        """
+
         if self.direction == "Z":
             if self.diffplot.get() == False:
                 self.canvas.place(
@@ -965,6 +1017,8 @@ class MainApplication(tk.Frame):
                     relheight=1, relwidth=1, relx=0.65, rely=0.5, anchor=tk.CENTER
                 )
 
+        """
+
         if len(self.DoseFigureHandler.plots) >= 2:
             self.addmenu.entryconfig(3, state=tk.NORMAL)
             self.normmenu.entryconfig(12, state=tk.DISABLED)
@@ -989,11 +1043,15 @@ class MainApplication(tk.Frame):
             self.menubar.add_cascade(label="Graph", menu=self.normmenu)
             self.menuflag = True
         self.image_on_canvas = self.canvas.create_image(
-            0, 0, anchor=tk.NW, image=self.photoimage
+            self.winfo_width() // 2,
+            self.winfo_height() // 2,
+            anchor=tk.CENTER,
+            image=self.photoimage,
         )
 
         self.canvas.image = self.photoimage
         self.canvas.itemconfig(self.image_on_canvas, image=self.canvas.image)
+        self.canvas.pack(side=tk.TOP, fill="both", expand=True)
 
         for i in range(len(self.DoseFigureHandler.plots)):
             normdiff = 0
@@ -1114,99 +1172,132 @@ class MainApplication(tk.Frame):
             self.show_preview()
         return
 
-    def handle_configure(self, event):
+    def handle_configure(self, event=None):
 
         """
         Dynamically resizes the graph, rename boxes and zoom window selector
         according to the window size and name length
         """
 
-        try:
-            image_width = event.width
-            image_height = event.height
-            width_factor = image_width / self.photoimage.width()
-            height_factor = image_height / self.photoimage.height()
+        deltax = self.winfo_width() // 2 - self.center[0]
+        deltay = self.winfo_height() // 2 - self.center[1]
+        self.center = [self.winfo_width() // 2, self.winfo_height() // 2]
 
-            if width_factor <= height_factor:
-                scale_factor = width_factor
-            else:
-                scale_factor = height_factor
+        self.logocanvas.move(self.logo_on_canvas, deltax, deltay)
 
-            self.resizable_image = ImageTk.getimage(self.photoimage)
-            self.resized_image = self.resizable_image.resize(
-                (
-                    int(self.photoimage.width() * scale_factor),
-                    int(self.photoimage.height() * scale_factor),
-                ),
-                Image.ANTIALIAS,
-            )
-            self.canvas.image = ImageTk.PhotoImage(self.resized_image)
-            self.canvas.itemconfig(self.image_on_canvas, image=self.canvas.image)
-        except AttributeError:
-            pass
+        if len(self.rename_boxes) > 0:
 
-        temp = self.rename_boxes[: len(self.DoseFigureHandler.plots)]
-        if len(self.rename_boxes) == 1:
-            temp = self.rename_boxes
+            if time.time() > self.starttime + 0.001:
+                try:
+                    image_width = event.width
+                    image_height = event.height
+                    width_factor = image_width / self.photoimage.width()
+                    height_factor = image_height / self.photoimage.height()
 
-        self.canvas.delete("rename")
-        self.rename_boxes = []
-        for i in range(len(temp)):
-            x = self.canvas.image.width()
-            y = self.canvas.image.height()
-            normdiff = 0
-            if self.norm.get() == False:
-                normdiff = 0.035
-            factor = (self.canvas.image.width() / self.canvas.image.height()) / 2
-            self.rename_boxes += [
-                self.canvas.create_rectangle(
-                    (
-                        -0.00833
-                        * max(
-                            map(
-                                len,
-                                [
-                                    plot.filename
-                                    for plot in self.DoseFigureHandler.plots
-                                ],
-                            )
-                        )
-                        + 0.94633
+                    if width_factor <= height_factor:
+                        scale_factor = width_factor
+                    else:
+                        scale_factor = height_factor
+
+                    self.resizable_image = ImageTk.getimage(self.photoimage)
+                    self.resized_image = self.resizable_image.resize(
+                        (
+                            int(self.photoimage.width() * scale_factor),
+                            int(self.photoimage.height() * scale_factor),
+                        ),
+                        Image.ANTIALIAS,
                     )
-                    * x,
-                    (0.023 + normdiff + 0.042 * i) * y * factor,
-                    0.988 * x,
-                    (0.065 + normdiff + 0.042 * i) * y * factor,
+                    self.canvas.image = ImageTk.PhotoImage(self.resized_image)
+                    self.canvas.itemconfig(
+                        self.image_on_canvas, image=self.canvas.image
+                    )
+                except AttributeError:
+                    pass
+
+            coords = self.canvas.coords(self.image_on_canvas)
+            imdims = [self.canvas.image.width(), self.canvas.image.height()]
+            canvdims = [self.canvas.winfo_width(), self.canvas.winfo_height()]
+
+            temp = self.rename_boxes[: len(self.DoseFigureHandler.plots)]
+            if len(self.rename_boxes) == 1:
+                temp = self.rename_boxes
+
+            self.canvas.delete("rename")
+            self.rename_boxes = []
+            for i in range(len(temp)):
+                normdiff = 0
+                factor = 1
+                if self.norm.get() == False:
+                    normdiff = -0.025
+                if self.DoseFigureHandler.plots[0].direction == "Z":
+                    factor = 6 / 5
+
+                self.rename_boxes += [
+                    self.canvas.create_rectangle(
+                        coords[0]
+                        + imdims[0]
+                        * (
+                            0.44
+                            - 0.0085
+                            * max(
+                                map(
+                                    len,
+                                    [
+                                        plot.filename
+                                        for plot in self.DoseFigureHandler.plots
+                                    ],
+                                )
+                            )
+                        ),
+                        (coords[1] - imdims[1] * (0.478 - i * 0.035 + normdiff))
+                        * factor,
+                        coords[0] + imdims[0] * 0.49,
+                        (coords[1] - imdims[1] * (0.443 - i * 0.035 + normdiff))
+                        * factor,
+                        fill="",
+                        outline="",
+                        tags="rename",
+                    )
+                ]
+
+            self.canvas.delete("token")
+
+            if self.zoom.get() == True:
+                self.oval = self.canvas.create_oval(
+                    self.pixelx * (self.canvas.image.width())
+                    - 5
+                    + (canvdims[0] - imdims[0]) // 2,
+                    self.pixely * (self.canvas.image.height())
+                    + (canvdims[1] - imdims[1]) // 2
+                    - 5,
+                    self.pixelx * (self.canvas.image.width())
+                    + 5
+                    + (canvdims[0] - imdims[0]) // 2,
+                    self.pixely * (self.canvas.image.height())
+                    + 5
+                    + (canvdims[1] - imdims[1]) // 2,
                     fill="",
                     outline="",
-                    tags="rename",
+                    tags="token",
                 )
-            ]
 
-        self.canvas.delete("token")
+            self.canvas.delete("xaxis")
+            if len(self.DoseFigureHandler.plots) >= 1:
+                coords = self.canvas.coords(self.image_on_canvas)
+                xbox = self.canvas.create_rectangle(
+                    coords[0] - imdims[0] * (0.035 + normdiff / 4),
+                    imdims[1] * 0.95 + (canvdims[1] - imdims[1]) // 2,
+                    coords[0] + imdims[0] * (0.065 - normdiff / 4),
+                    imdims[1] + (canvdims[1] - imdims[1]) // 2,
+                    tags="xaxis",
+                    outline="",
+                    fill="",
+                )
+                self.rename_boxes += [xbox]
 
-        if self.zoom.get() == True:
-            self.oval = self.canvas.create_oval(
-                self.pixelx * self.canvas.image.width() - 5,
-                self.pixely * self.canvas.image.height() - 5,
-                self.pixelx * self.canvas.image.width() + 5,
-                self.pixely * self.canvas.image.height() + 5,
-                fill="",
-                outline="",
-                tags="token",
-            )
-        self.canvas.delete("xaxis")
-        if len(self.DoseFigureHandler.plots) >= 1:
-            xbox = self.canvas.create_rectangle(
-                0.43 * self.canvas.image.width(),
-                0.95 * self.canvas.image.height(),
-                0.6 * self.canvas.image.width(),
-                self.canvas.image.height(),
-                tags="xaxis",
-                outline="",
-                fill="",
-            )
-            self.rename_boxes += [xbox]
+            self.canvas.move(self.image_on_canvas, deltax, deltay)
+
+        self.starttime = time.time()
 
     def check_hand(self, e):
 
@@ -1293,7 +1384,7 @@ class MainApplication(tk.Frame):
                         and bbox[3] > e.y
                     ):
                         newcolor = askcolor(color=self.DoseFigureHandler.colors[index])
-                        if newcolor != None:
+                        if newcolor != (None, None):
                             self.DoseFigureHandler.colors[index] = newcolor[1]
                             self.profile.set_attribute(
                                 "colors", self.DoseFigureHandler.colors
