@@ -32,9 +32,7 @@ def topasgraphsim():
 
             if drag.install_success == True:
                 python = sys.executable
-                args = os.path.join(
-                    os.path.dirname(os.path.realpath(__file__)), "topasgraphsim.py"
-                )
+                args = "-m topasgraphsim"
                 os.execl(python, python, args)
                 return
 
@@ -44,9 +42,7 @@ def topasgraphsim():
             except RuntimeError:
                 ProfileHandler().set_attribute("draganddrop", False)
                 python = sys.executable
-                args = os.path.join(
-                    os.path.dirname(os.path.realpath(__file__)), "topasgraphsim.py"
-                )
+                args = args = "-m topasgraphsim"
                 os.execl(python, python, args)
                 return
         else:
